@@ -19,7 +19,6 @@ fm_is_within <- function(x, y, ...) {
 }
 
 
-
 # fm_basis ####
 
 #' @title Compute mapping matrix between mesh function space and points
@@ -343,10 +342,10 @@ fm_basis.fm_collect <- function(x,
 #' weight for each row of the basis matrix)
 #' @export
 fm_basis.matrix <- function(x, ok = NULL, weights = NULL, ..., full = FALSE) {
-  if (!full) {
+  if (!full && is.null(weights)) {
     return(x)
   }
-  fm_basis(list(A = x, ok = ok, ...), weights = weights, full = TRUE)
+  fm_basis(list(A = x, ok = ok, ...), weights = weights, full = full)
 }
 
 #' @describeIn fm_basis Creates a new `fm_basis` object with elements `A` and
@@ -357,10 +356,10 @@ fm_basis.matrix <- function(x, ok = NULL, weights = NULL, ..., full = FALSE) {
 #'   returns the matrix unchanged.
 #' @export
 fm_basis.Matrix <- function(x, ok = NULL, weights = NULL, ..., full = FALSE) {
-  if (!full) {
+  if (!full && is.null(weights)) {
     return(x)
   }
-  fm_basis(list(A = x, ok = ok, ...), weights = weights, full = TRUE)
+  fm_basis(list(A = x, ok = ok, ...), weights = weights, full = full)
 }
 
 #' @describeIn fm_basis Creates a new `fm_basis` object from a plain list
@@ -408,8 +407,6 @@ fm_basis.fm_evaluator <- function(x, ..., full = FALSE) {
 }
 
 
-
-
 internal_spline_mesh_1d <- function(interval,
                                     m,
                                     degree,
@@ -464,6 +461,39 @@ internal_spline_mesh_1d <- function(interval,
 }
 
 
+# fmesher_spherical_harmonics_gsl <- function(loc,
+#                                             max_order,
+#                                             rot_inv) {
+#   n <- max_order
+#   loc <- loc / rowSums(loc^2)^0.5
+#   if (rot_inv) {
+#     basis <- matrix(0, nrow(loc), n + 1)
+#     for (l in seq(0, n)) {
+#       basis[, l + 1] <- sqrt(2 * l + 1) *
+#         gsl::legendre_Pl(l = l, x = loc[, 3])
+#     }
+#   } else {
+#     angle <- atan2(loc[, 2], loc[, 1])
+#     basis <- matrix(0, nrow(loc), (n + 1)^2)
+#     for (l in seq(0, n)) {
+#       basis[, 1 + l * (l + 1)] <-
+#         sqrt(2 * l + 1) *
+#         gsl::legendre_Pl(l = l, x = loc[, 3])
+#       for (m in seq_len(l)) {
+#         scaling <- sqrt(2 * (2 * l + 1) * exp(lgamma(l - m + 1) -
+#                                                 lgamma(l + m + 1)))
+#         poly <- gsl::legendre_Plm(l = l, m = m, x = loc[, 3])
+#         basis[, 1 + l * (l + 1) - m] <-
+#           scaling * sin(-m * angle) * poly
+#         basis[, 1 + l * (l + 1) + m] <-
+#           scaling * cos(m * angle) * poly
+#       }
+#     }
+#   }
+#   basis
+# }
+
+
 #' Basis functions for mesh manifolds
 #'
 #' Calculate basis functions on [fm_mesh_1d()] or [fm_mesh_2d()],
@@ -586,60 +616,19 @@ fm_raw_basis <- function(mesh,
     if (!identical(mesh$manifold, "S2")) {
       stop("Only know how to make spherical harmonics on S2.")
     }
-    # With GSL activated:
-    #        if (rot.inv) {
-    #            basis <- (inla.fmesher.smorg(
-    #                mesh$loc,
-    #                mesh$graph$tv,
-    #                sph0 = n
-    #            )$sph0)
-    #        } else {
-    #            basis <- (inla.fmesher.smorg(
-    #                mesh$loc,
-    #                mesh$graph$tv,
-    #                sph = n
-    #            )$sph)
-    #        }
-
-    fm_require_stop(
-      "gsl",
-      "The 'gsl' R package is needed for spherical harmonics."
-    )
-
     # Make sure we have radius-1 coordinates
     loc <- mesh$loc / rowSums(mesh$loc^2)^0.5
-    if (rot.inv) {
-      basis <- matrix(0, nrow(loc), n + 1)
-      for (l in seq(0, n)) {
-        basis[, l + 1] <- sqrt(2 * l + 1) *
-          gsl::legendre_Pl(l = l, x = loc[, 3])
-      }
-    } else {
-      angle <- atan2(loc[, 2], loc[, 1])
-      basis <- matrix(0, nrow(loc), (n + 1)^2)
-      for (l in seq(0, n)) {
-        basis[, 1 + l * (l + 1)] <-
-          sqrt(2 * l + 1) *
-            gsl::legendre_Pl(l = l, x = loc[, 3])
-        for (m in seq_len(l)) {
-          scaling <- sqrt(2 * (2 * l + 1) * exp(lgamma(l - m + 1) -
-            lgamma(l + m + 1)))
-          poly <- gsl::legendre_Plm(l = l, m = m, x = loc[, 3])
-          basis[, 1 + l * (l + 1) - m] <-
-            scaling * sin(-m * angle) * poly
-          basis[, 1 + l * (l + 1) + m] <-
-            scaling * cos(m * angle) * poly
-        }
-      }
-    }
+    basis <- fmesher_spherical_harmonics(
+      loc,
+      max_order = as.integer(n),
+      rot_inv = isTRUE(rot.inv)
+    )
   }
 
-  return(basis)
+  basis
 }
 
 
-
-
 #' @title Internal helper functions for mesh field evaluation
 #'
 #' @description Methods called internally by [fm_basis()] methods.
@@ -1171,7 +1160,6 @@ fm_basis_mesh_1d <- function(mesh,
 }
 
 
-
 # Plain B-spline basis evaluation by Farin eq 10.13-10.14,
 # building the basis function matrices recursively via index vectors
 internal_bspline <- function(x, knots, degree = 1, deriv = 0) {
@@ -1234,7 +1222,7 @@ internal_bspline <- function(x, knots, degree = 1, deriv = 0) {
     #    message("knots: ", knots)
     #    message("unique j: ", unique(basis$j))
   }
-  return(basis)
+  basis
 }
 
 
@@ -1316,12 +1304,10 @@ internal_bspline2 <- function(x, knots, degree = 1, deriv = 0) {
         (knots[l + deg + 1L] - knots[l + 1L])
     }
   }
-  return(basis)
+  basis
 }
 
 
-
-
 # Block methods ####
 
 #' Blockwise aggregation matrices
@@ -1402,7 +1388,7 @@ fm_block <- function(block = NULL,
 
   Matrix::sparseMatrix(
     i = info$block,
-    j = seq_len(length(info$block)),
+    j = seq_along(info$block),
     x = as.numeric(weights),
     dims = c(info$n_block, length(info$block))
   )
