@@ -142,11 +142,10 @@ fm_as_list <- function(x, ..., .class_stub = NULL) {
   }
 
   class(y) <- c("fm_list", "list")
-  return(y)
+  y
 }
 
 
-
 #' @export
 #' @describeIn fm_list The `...` arguments should be coercible to `fm_list`
 #' objects.
