@@ -16,12 +16,14 @@
 #' @param add If `TRUE`, add to the current plot, otherwise start a new
 #' plot.
 #' @param xlim,ylim X and Y axis limits for a new plot.
-#' @param rgl If `TRUE`, use `rgl` for plotting.
 #' @param asp Aspect ratio for new plots. Default 1.
 #' @param axes logical; whether axes should be drawn on the plot.
 #' Default FALSE.
 #' @param xlab,ylab character; labels for the axes.
 #' @param \dots Additional parameters, passed on to graphics methods.
+#' @param rgl `r lifecycle::badge("deprecated")` since `0.5.0.9000`
+#'   in favour of the [plot_rgl()] and [lines_rgl()] methods.
+#'   If `TRUE`, use `rgl` for plotting.
 #' @author Finn Lindgren <Finn.Lindgren@@gmail.com>
 #' @returns None
 #' @seealso [fm_segm()], [plot.fm_mesh_2d]
@@ -31,7 +33,7 @@
 #' lines(fm_segm(fmexample$mesh, boundary = FALSE), col = 2)
 #'
 plot.fm_segm <- function(x, ..., add = FALSE) {
-  lines(x, add = add, rgl = FALSE, ...)
+  lines(x, add = add, ...)
 }
 
 #' @param visibility If "front" only display mesh faces with normal pointing
@@ -41,21 +43,26 @@ plot.fm_segm <- function(x, ..., add = FALSE) {
 lines.fm_segm <- function(x, loc = NULL, col = NULL,
                           colors = c("black", "blue", "red", "green"),
                           add = TRUE, xlim = NULL, ylim = NULL,
-                          rgl = FALSE, asp = 1,
+                          asp = 1,
                           axes = FALSE,
                           xlab = "",
                           ylab = "",
                           visibility = "front",
+                          rgl = deprecated(),
                           ...) {
-  if (rgl) {
-    lines_rgl(
+  if (lifecycle::is_present(rgl)) {
+    lifecycle::deprecate_warn(
+      "0.5.0.9000", "lines.fm_segm(rgl = )",
+      "lines_rgl()"
+    )
+    return(lines_rgl(
       x,
       loc = loc,
       col = col,
       colors = colors,
       add = add,
       ...
-    )
+    ))
   }
   segm <- x
   if (!is.null(segm$loc)) {
@@ -103,7 +110,7 @@ lines.fm_segm <- function(x, loc = NULL, col = NULL,
       ...
     )
   }
-  return(invisible(dev))
+  invisible(dev)
 }
 
 
@@ -164,7 +171,6 @@ lines.fm_mesh_2d <- function(x, ..., add = TRUE) {
 }
 
 
-
 #' @rdname plot.fm_mesh_2d
 #' @param rgl Deprecated
 #' @inheritParams plot.fm_segm
@@ -173,27 +179,37 @@ lines.fm_mesh_2d <- function(x, ..., add = TRUE) {
 #' mesh <- fm_mesh_2d(cbind(0, 1), offset = c(1, 1.5), max.edge = 0.5)
 #' plot(mesh)
 plot.fm_mesh_2d <- function(
-    x,
-    col = "white",
-    t.sub = seq_len(nrow(x$graph$tv)),
-    add = FALSE,
-    lwd = 1,
-    xlim = range(x$loc[, 1]),
-    ylim = range(x$loc[, 2]),
-    main = NULL,
-    size = 1,
-    draw.vertices = FALSE,
-    vertex.color = "black",
-    draw.edges = TRUE,
-    edge.color = rgb(0.3, 0.3, 0.3),
-    draw.segments = draw.edges,
-    rgl = deprecated(),
-    visibility = "front",
-    asp = 1,
-    axes = FALSE,
-    xlab = "",
-    ylab = "",
-    ...) {
+  x,
+  col = "white",
+  t.sub = seq_len(nrow(x$graph$tv)),
+  add = FALSE,
+  lwd = 1,
+  xlim = range(x$loc[, 1]),
+  ylim = range(x$loc[, 2]),
+  main = NULL,
+  size = 1,
+  draw.vertices = FALSE,
+  vertex.color = "black",
+  draw.edges = TRUE,
+  edge.color = rgb(0.3, 0.3, 0.3),
+  draw.segments = draw.edges,
+  rgl = deprecated(),
+  visibility = "front",
+  asp = 1,
+  axes = FALSE,
+  xlab = "",
+  ylab = "",
+  ...
+) {
+  if (lifecycle::is_present(rgl)) {
+    lifecycle::deprecate_stop(
+      "0.1.0",
+      "plot.fm_mesh_2d(rgl = )",
+      "plot_rgl()"
+    )
+    return(plot_rgl(x, ...))
+  }
+
   force(t.sub)
   force(xlim)
   force(ylim)
@@ -285,7 +301,7 @@ plot.fm_mesh_2d <- function(
       )
     }
   }
-  return(invisible())
+  invisible()
 }
 
 
@@ -308,14 +324,10 @@ get_tv_sub <- function(tv, loc, t.sub, visibility = "front") {
     tv <- tv[ok, , drop = FALSE]
     t.sub <- t.sub[ok]
   }
-  return(list(tv = tv, t.sub = t.sub))
+  list(tv = tv, t.sub = t.sub)
 }
 
 
-
-
-
-
 # plot_rgl ####
 
 
@@ -348,7 +360,7 @@ get_tv_sub <- function(tv, loc, t.sub, visibility = "front") {
 #' @export
 #' @examples
 #' \donttest{
-#' if (interactive() && require("rgl")) {
+#' if (interactive() && requireNamespace("rgl")) {
 #'   mesh <- fm_rcdt_2d(globe = 10)
 #'   plot_rgl(mesh, col = mesh$loc[, 1])
 #' }
@@ -400,7 +412,7 @@ lines_rgl.fm_segm <- function(x, loc = NULL, col = NULL,
       ...
     )
   }
-  return(invisible(dev))
+  invisible(dev)
 }
 
 #' @export
@@ -471,9 +483,7 @@ plot_rgl.fm_mesh_2d <- function(x, col = "white", color.axis = NULL,
   )
 
   tTV <- t(TV)
-  Tx <- S[tTV, 1]
-  Ty <- S[tTV, 2]
-  Tz <- S[tTV, 3]
+  Txyz <- S[tTV, ]
   if (length(colors$colors) == 1) {
     ## One color
     Tcol <- colors$colors
@@ -524,12 +534,11 @@ plot_rgl.fm_mesh_2d <- function(x, col = "white", color.axis = NULL,
     rgl::points3d(S_, color = "black", ...)
   }
   if (draw.edges) {
-    rgl::lines3d(Ec[, 1], Ec[, 2], Ec[, 3], color = Ecol, lwd = lwd, ...)
+    rgl::lines3d(Ec, color = Ecol, lwd = lwd, ...)
   }
   if (draw.faces) {
-    rgl::triangles3d(Tx,
-      Ty,
-      Tz,
+    rgl::triangles3d(
+      Txyz,
       color = Tcol,
       specular = specular,
       alpha = Talpha,
@@ -537,7 +546,7 @@ plot_rgl.fm_mesh_2d <- function(x, col = "white", color.axis = NULL,
     )
   }
 
-  return(invisible(dev))
+  invisible(dev)
 }
 
 #' @rdname plot_rgl
@@ -560,7 +569,6 @@ lines_rgl.fm_segm_list <- function(x, ...) {
 }
 
 
-
 ## library(geometry)
 ## S = cbind(x=rnorm(30), y=rnorm(30), z=0)
 ## TV = delaunayn(S[, 1:2]) # NOTE: inconsistent triangle orders, only for test.
@@ -578,7 +586,6 @@ lines_rgl.fm_segm_list <- function(x, ...) {
 ## Ecol = Ecol[tETV]
 
 
-
 #' Generate text RGB color specifications.
 #'
 #' Generates a text RGB color specification matrix based on a color palette.
@@ -668,5 +675,5 @@ fm_generate_colors <- function(color,
     stop("color specification must be character, matrix, or vector.")
   }
 
-  return(list(colors = colors, alpha = alpha))
+  list(colors = colors, alpha = alpha)
 }
